==> v1.4.1.tar.gz: logstash/CONTRIBUTING.md <==
# Contributing to logstash

All contributions are welcome: ideas, patches, documentation, bug reports,
complaints, etc!

Programming is not a required skill, and there are many ways to help out!
It is more important to us that you are able to contribute.

That said, some basic guidelines, which you are free to ignore :)

## Want to learn?

Want to lurk about and see what others are doing with logstash? 

* The irc channel (#logstash on irc.freenode.org) is a good place for this
* The [mailing list](http://groups.google.com/group/logstash-users) is also
  great for learning from others.

## Got Questions?

Have a problem you want logstash to solve for you? 

* You can email the [mailing list](http://groups.google.com/group/logstash-users)
* alternately, you are welcome to join the IRC channel #logstash on
irc.freenode.org and ask for help there!

## Have an Idea or Feature Request?

* File a ticket on [jira](https://logstash.jira.com/secure/Dashboard.jspa), or email the
  [mailing list](http://groups.google.com/group/logstash-users), or email
  me personally (jls@semicomplete.com) if that is more comfortable.

## Something Not Working? Found a Bug?

If you think you found a bug, it probably is a bug.

* File it on [jira](https://logstash.jira.com/secure/Dashboard.jspa)
* or the [mailing list](http://groups.google.com/group/logstash-users).

# Contributing Documentation and Code Changes

If you have a bugfix or new feature that you would like to contribute to
logstash, and you think it will take more than a few minutes to produce the fix
(ie; write code), it is worth discussing the change with the logstash users and developers first! You can reach us via [jira](https://logstash.jira.com/secure/Dashboard.jspa), the [mailing list](http://groups.google.com/group/logstash-users), or via IRC (#logstash on freenode irc)

## Contribution Steps

1. Test your changes! Run the test suite ('make test') 
2. Please make sure you have signed our [Contributor License
   Agreement](http://www.elasticsearch.org/contributor-agreement/). We are not
   asking you to assign copyright to us, but to give us the right to distribute
   your code without restriction. We ask this of all contributors in order to
   assure our users of the origin and continuing existence of the code. You
   only need to sign the CLA once.
3. Send a pull request! Push your changes to your fork of the repository and
   [submit a pull
   request](https://help.github.com/articles/using-pull-requests). In the pull
   request, describe what your changes do and mention any jira issues related
   to the pull request.

==> v1.5.0.rc1.tar.gz: logstash/CONTRIBUTING.md <==
# Contributing to logstash

All contributions are welcome: ideas, patches, documentation, bug reports,
complaints, etc!

Programming is not a required skill, and there are many ways to help out!
It is more important to us that you are able to contribute.

That said, some basic guidelines, which you are free to ignore :)

## Want to learn?

Want to lurk about and see what others are doing with logstash? 

* The irc channel (#logstash on irc.freenode.org) is a good place for this
* The [mailing list](http://groups.google.com/group/logstash-users) is also
  great for learning from others.

## Got Questions?

Have a problem you want logstash to solve for you? 

* You can email the [mailing list](http://groups.google.com/group/logstash-users)
* alternately, you are welcome to join the IRC channel #logstash on
irc.freenode.org and ask for help there!

## Have an Idea or Feature Request?

* File a ticket on [github](https://github.com/elasticsearch/logstash/issues), or email the
  [mailing list](http://groups.google.com/group/logstash-users), or email
  me personally (jls@semicomplete.com) if that is more comfortable.

## Something Not Working? Found a Bug?

If you think you found a bug, it probably is a bug.

* File it on [github](https://github.com/elasticsearch/logstash/issues)
* or the [mailing list](http://groups.google.com/group/logstash-users).

# Contributing Documentation and Code Changes

If you have a bugfix or new feature that you would like to contribute to
logstash, and you think it will take more than a few minutes to produce the fix
(ie; write code), it is worth discussing the change with the logstash users and developers first! You can reach us via [github](https://github.com/elasticsearch/logstash/issues), the [mailing list](http://groups.google.com/group/logstash-users), or via IRC (#logstash on freenode irc)

## Contribution Steps

1. Test your changes! Run the test suite ('make test') 
2. Please make sure you have signed our [Contributor License
   Agreement](http://www.elasticsearch.org/contributor-agreement/). We are not
   asking you to assign copyright to us, but to give us the right to distribute
   your code without restriction. We ask this of all contributors in order to
   assure our users of the origin and continuing existence of the code. You
   only need to sign the CLA once.
3. Send a pull request! Push your changes to your fork of the repository and
   [submit a pull
   request](https://help.github.com/articles/using-pull-requests). In the pull
   request, describe what your changes do and mention any bugs/issues related
   to the pull request.
